Package: qtl2convert
Version: 0.36
Date: 2026-07-17
Title: Convert Data among QTL Mapping Packages
Description: Functions to convert data structures among the 'qtl2', 'qtl', and 'DOQTL' packages for mapping quantitative trait loci (QTL).
Author: Karl W Broman [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4914-6671>)
Maintainer: Karl W Broman <broman@wisc.edu>
Authors@R: person("Karl W", "Broman", role=c("aut", "cre"),
                  email="broman@wisc.edu", comment=c(ORCID = "0000-0002-4914-6671"))
Depends: R (>= 3.1.0)
Imports: Rcpp (>= 0.12.12), qtl (>= 1.40-8), qtl2 (>= 0.18), utils,
        stats
Suggests: testthat, devtools, roxygen2
License: GPL-3
URL: https://kbroman.org/qtl2/, https://github.com/rqtl/qtl2convert
BugReports: https://github.com/rqtl/qtl2convert/issues
LinkingTo: Rcpp
Encoding: UTF-8
ByteCompile: true
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-07-17 19:41:10 UTC; kbroman
Repository: CRAN
Date/Publication: 2026-07-17 20:20:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-07-17 22:18:54 UTC; unix
Archs: qtl2convert.so.dSYM
