# Generated by roxygen2: do not edit by hand

export(cbind_smother)
export(count_unique_geno)
export(cross2_do_to_genail)
export(cross2_do_to_genail8)
export(cross2_ril_to_genril)
export(encode_geno)
export(find_consensus_geno)
export(find_unique_geno)
export(map_df_to_list)
export(map_list_to_df)
export(probs_doqtl_to_qtl2)
export(probs_qtl2_to_array)
export(probs_qtl2_to_doqtl)
export(probs_qtl_to_qtl2)
export(scan_qtl2_to_qtl)
export(scan_qtl_to_qtl2)
export(write2csv)
importFrom(Rcpp,sourceCpp)
importFrom(qtl,getgenonames)
importFrom(qtl,getid)
importFrom(qtl,getsex)
importFrom(qtl,nind)
importFrom(qtl2,batch_vec)
importFrom(qtl2,cbind_expand)
importFrom(stats,setNames)
importFrom(utils,write.table)
useDynLib(qtl2convert, .registration=TRUE)
