#' @keywords internal
#' @importFrom Rcpp sourceCpp
#' @useDynLib qtl2convert, .registration=TRUE
#'
#' @section Vignettes:
#' * [user guide](https://kbroman.org/qtl2/assets/vignettes/user_guide.html)
#' * [input file formats](https://kbroman.org/qtl2/assets/vignettes/input_files.html)
#' * [preparing DO mouse data for R/qtl2](https://kbroman.org/qtl2/pages/prep_do_data.html)
#' * [differences between R/qtl and R/qtl2](https://kbroman.org/qtl2/assets/vignettes/rqtl_diff.html)
#' * [developer guide](https://kbroman.org/qtl2/assets/vignettes/developer_guide.html)
"_PACKAGE"
