# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

.count_unique_geno <- function(g) {
    .Call(`_qtl2convert_count_unique_geno`, g)
}

.encode_geno <- function(g, old_values, new_values) {
    .Call(`_qtl2convert_encode_geno`, g, old_values, new_values)
}

.find_consensus_geno <- function(g) {
    .Call(`_qtl2convert_find_consensus_geno`, g)
}

.find_unique_geno <- function(g) {
    .Call(`_qtl2convert_find_unique_geno`, g)
}

